from datetime import datetime

from pydantic import Field, BaseModel


class CreateTipSchema(BaseModel):
    amount: int = Field(
        ...,
        description="Amount of the tip in RUB currency",
        ge=10,
    )
    text: str | None = Field(
        default=None,
        description="Text of the tip",
    )
    from_user: str | None = Field(
        default=None,
        description="User who sent the tip",
    )


class DonationSchema(BaseModel):
    id: int
    widget_id: int
    order_id: str = Field(..., alias="order_id")
    status: str
    text: str
    amount: float
    donat_user: str = Field(..., alias="donat_user")
    accepted_time: datetime
    show_name: bool
    show_text: bool
    play_content: bool
    showed_time: datetime
    paid_time: datetime


class AllDonatesSchema(BaseModel):
    donates: list[DonationSchema]


class TotalDonationStat(BaseModel):
    total_amount: float
    donations_count: int

class MonthlyDonationStat(BaseModel):
    date: datetime
    amount_collected: float
    donations_count: int

class DonationPeriodStatSchema(BaseModel):
    donation_sum: TotalDonationStat
    donations: list[MonthlyDonationStat]